==> f2-4.0.46.tgz: package/es/components/guide/views/Tag.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import { jsx } from '../../../jsx';
var defaultProps = {
  offsetX: 0,
  offsetY: 0,
  points: [],
  direct: 'tl',
  side: 6,
  autoAdjust: true
};
var defaultStyle = {
  container: {
    fill: '#1677FF',
    radius: 2,
    padding: [3, 5]
  },
  text: {
    fontSize: '22px',
    fill: '#fff'
  },
  arrow: {
    fill: '#1677FF'
  }
};
export default (function (props, context) {
  var cfg = _objectSpread(_objectSpread({}, defaultProps), props);
  var points = cfg.points,
    content = cfg.content,
    offsetX = cfg.offsetX,
    offsetY = cfg.offsetY,
    direct = cfg.direct,
    side = cfg.side,
    autoAdjust = cfg.autoAdjust,
    canvasWidth = cfg.canvasWidth,
    canvasHeight = cfg.canvasHeight,
    guideBBox = cfg.guideBBox,
    background = cfg.background,
    textStyle = cfg.textStyle,
    triggerRef = cfg.triggerRef;
  var _ref = points[0] || {},
    x = _ref.x,
    y = _ref.y;
  var _ref2 = guideBBox || {},
    guideWidth = _ref2.width,
    guideHeight = _ref2.height;
  var offsetXNum = context.px2hd(offsetX);
  var offsetYNum = context.px2hd(offsetY);
  var posX = x + (offsetXNum || 0);
  var posY = y + (offsetYNum || 0);
  var _getDirect = function _getDirect(point) {
    var newDirect = direct;
    var x = point.x,
      y = point.y;
    var vertical = newDirect[0];
    var horizontal = newDirect[1];
    // adjust for vertical direction
    if (vertical === 't' && y - side - guideHeight < 0) {
      vertical = 'b';
    } else if (vertical === 'b' && y + side + guideHeight > canvasHeight) {
      vertical = 't';
    }
    // adjust for horizontal direction
    var diff = vertical === 'c' ? side : 0;
    if (horizontal === 'l' && x - diff - guideWidth < 0) {
      horizontal = 'r';
    } else if (horizontal === 'r' && x + diff + guideWidth > canvasWidth) {
      horizontal = 'l';
    } else if (horizontal === 'c') {
      if (guideWidth / 2 + x + diff > canvasWidth) {
        horizontal = 'l';
      } else if (x - guideWidth / 2 - diff < 0) {
        horizontal = 'r';
      }
    }
    newDirect = vertical + horizontal;
    return newDirect;
  };
  var _getArrowPoints = function _getArrowPoints(direct) {
    var arrowPoints = [];
    // const { minX, minY } = guideBBox || {};
    if (direct === 'tl') {
      arrowPoints = [{
        x: posX,
        y: posY - side - 1
      }, {
        x: posX,
        y: posY
      }, {
        x: posX - side,
        y: posY - side - 1
      }];
      posX -= guideWidth || 0;
      posY = posY - (guideHeight || 0) - side;
    } else if (direct === 'cl') {
      arrowPoints = [{
        x: posX - side - 1,
        y: posY - side
      }, {
        x: posX - side - 1,
        y: posY + side
      }, {
        x: posX,
        y: posY
      }];
      posX = posX - (guideWidth || 0) - side;
      posY -= guideHeight / 2 || 0;
    } else if (direct === 'bl') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY + side + 1
      }, {
        x: posX - side,
        y: posY + side + 1
      }];
      posX = posX - (guideWidth || 0);
      posY += side;
    } else if (direct === 'bc') {
      // 有问题
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX - side,
        y: posY + side + 1
      }, {
        x: posX + side,
        y: posY + side + 1
      }];
      posX = posX - (guideWidth / 2 || 0);
      posY = posY + side;
    } else if (direct === 'br') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY + side + 1
      }, {
        x: posX + side,
        y: posY + side + 1
      }];
      posY += side;
    } else if (direct === 'cr') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX + side,
        y: posY - side
      }, {
        x: posX + side,
        y: posY + side
      }];
      posX += side;
      posY -= guideHeight / 2 || 0;
    } else if (direct === 'tr') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY - side - 1
      }, {
        x: posX + side,
        y: posY - side - 1
      }];
      posY = posY - (guideHeight || 0) - side;
    } else if (direct === 'tc') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX - side,
        y: posY - side - 1
      }, {
        x: posX + side,
        y: posY - side - 1
      }];
      posX -= guideWidth / 2 || 0;
      posY = posY - (guideHeight || 0) - side;
    }
    return arrowPoints;
  };
  var dr = autoAdjust ? _getDirect(points[0]) : direct;
  var arrowPoints = _getArrowPoints(dr);
  return jsx("group", {
    attrs: _objectSpread({
      fill: defaultStyle.container.fill,
      radius: defaultStyle.container.radius
    }, background),
    style: _objectSpread({
      left: posX,
      top: posY,
      padding: defaultStyle.container.padding
    }, background),
    ref: triggerRef
  }, jsx("text", {
    attrs: _objectSpread({
      text: content,
      fontSize: defaultStyle.text.fontSize,
      fill: defaultStyle.text.fill
    }, textStyle)
  }), guideBBox && jsx("polygon", {
    attrs: {
      points: arrowPoints,
      fill: (background === null || background === void 0 ? void 0 : background.fill) || defaultStyle.arrow.fill
    }
  }));
});

==> f2-5.0.5.tgz: package/es/components/guide/views/Tag.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import { jsx } from '../../../index';
var defaultProps = {
  offsetX: 0,
  offsetY: 0,
  points: [],
  direct: 'tl',
  side: '8px',
  autoAdjust: true
};
var defaultStyle = {
  container: {
    fill: '#1677FF',
    radius: '4px',
    padding: ['4px', '8px']
  },
  text: {
    fontSize: '22px',
    fill: '#fff'
  },
  arrow: {
    fill: '#1677FF'
  }
};
export default (function (props, context) {
  var px2hd = context.px2hd;
  var cfg = _objectSpread(_objectSpread({}, defaultProps), props);
  var _px2hd = px2hd(cfg),
    points = _px2hd.points,
    content = _px2hd.content,
    offsetX = _px2hd.offsetX,
    offsetY = _px2hd.offsetY,
    direct = _px2hd.direct,
    side = _px2hd.side,
    autoAdjust = _px2hd.autoAdjust,
    canvasWidth = _px2hd.canvasWidth,
    canvasHeight = _px2hd.canvasHeight,
    guideBBox = _px2hd.guideBBox,
    background = _px2hd.background,
    textStyle = _px2hd.textStyle,
    triggerRef = _px2hd.triggerRef;
  var _ref = points[0] || {},
    x = _ref.x,
    y = _ref.y;
  var _ref2 = guideBBox || {},
    guideWidth = _ref2.width,
    guideHeight = _ref2.height;
  var offsetXNum = context.px2hd(offsetX);
  var offsetYNum = context.px2hd(offsetY);
  var posX = x + (offsetXNum || 0);
  var posY = y + (offsetYNum || 0);
  var _getDirect = function _getDirect(point) {
    var newDirect = direct;
    var x = point.x,
      y = point.y;
    var vertical = newDirect[0];
    var horizontal = newDirect[1];
    // adjust for vertical direction
    if (vertical === 't' && y - side - guideHeight < 0) {
      vertical = 'b';
    } else if (vertical === 'b' && y + side + guideHeight > canvasHeight) {
      vertical = 't';
    }
    // adjust for horizontal direction
    var diff = vertical === 'c' ? side : 0;
    if (horizontal === 'l' && x - diff - guideWidth < 0) {
      horizontal = 'r';
    } else if (horizontal === 'r' && x + diff + guideWidth > canvasWidth) {
      horizontal = 'l';
    } else if (horizontal === 'c') {
      if (guideWidth / 2 + x + diff > canvasWidth) {
        horizontal = 'l';
      } else if (x - guideWidth / 2 - diff < 0) {
        horizontal = 'r';
      }
    }
    newDirect = vertical + horizontal;
    return newDirect;
  };
  var _getArrowPoints = function _getArrowPoints(direct) {
    var arrowPoints = [];
    if (direct === 'tl') {
      arrowPoints = [{
        x: posX,
        y: posY - side - 1
      }, {
        x: posX,
        y: posY
      }, {
        x: posX - side,
        y: posY - side - 1
      }];
      posX -= guideWidth / 2 || 0;
      posY = posY - side;
    } else if (direct === 'cl') {
      arrowPoints = [{
        x: posX - side - 1,
        y: posY - side
      }, {
        x: posX - side - 1,
        y: posY + side
      }, {
        x: posX,
        y: posY
      }];
      posX = posX - (guideWidth / 2 || 0) - side;
      posY += (guideHeight / 2 || 0) - 1;
    } else if (direct === 'bl') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY + side + 1
      }, {
        x: posX - side,
        y: posY + side + 1
      }];
      posX = posX - (guideWidth / 2 || 0);
      posY += (guideHeight || 0) + side - 1;
    } else if (direct === 'bc') {
      // 有问题
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX - side,
        y: posY + side + 1
      }, {
        x: posX + side,
        y: posY + side + 1
      }];
      posY += (guideHeight || 0) + side - 1;
    } else if (direct === 'br') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY + side + 1
      }, {
        x: posX + side,
        y: posY + side + 1
      }];
      posX += guideWidth / 2 || 0;
      posY += (guideHeight || 0) + side - 1;
    } else if (direct === 'cr') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX + side,
        y: posY - side
      }, {
        x: posX + side,
        y: posY + side
      }];
      posX += (guideWidth / 2 || 0) + side;
      posY += guideHeight / 2 || 0;
    } else if (direct === 'tr') {
      arrowPoints = [{
        x: posX,
        y: posY
      }, {
        x: posX,
        y: posY - side - 1
      }, {
        x: posX + side,
        y: posY - side - 1
      }];
      posX += guideWidth / 2 || 0;
      posY = posY - side;
    } else if (direct === 'tc') {
      arrowPoints = [{
        x: guideWidth / 2,
        y: guideHeight + side
      }, {
        x: guideWidth / 2 - side,
        y: guideHeight - 1
      }, {
        x: guideWidth / 2 + side,
        y: guideHeight - 1
      }];
      posY = posY - guideHeight - side;
    }
    return arrowPoints;
  };
  var dr = autoAdjust ? _getDirect(points[0]) : direct;
  var arrowPoints = _getArrowPoints(dr);
  return jsx("group", {
    style: _objectSpread({
      x: posX,
      y: posY,
      fill: defaultStyle.container.fill,
      radius: defaultStyle.container.radius,
      padding: defaultStyle.container.padding
    }, background),
    ref: triggerRef
  }, jsx("rect", {
    style: _objectSpread({
      display: 'flex',
      fill: defaultStyle.container.fill,
      padding: defaultStyle.container.padding,
      radius: defaultStyle.container.radius
    }, background)
  }, jsx("text", {
    style: _objectSpread({
      text: content,
      fontSize: defaultStyle.text.fontSize,
      fill: defaultStyle.text.fill
    }, textStyle)
  })), guideBBox && jsx("polygon", {
    style: {
      points: arrowPoints.map(function (d) {
        return [d.x, d.y];
      }),
      fill: (background === null || background === void 0 ? void 0 : background.fill) || defaultStyle.arrow.fill
    }
  }));
});
